#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rb_build_versions %rb_default_ruby
%global rb_build_abi %rb_default_ruby_abi
%global rb_ruby_suffix %rb_default_ruby_suffix

%global vagrant_plugin_name vagrant-sshfs
%define mod_name %{vagrant_plugin_name}
%define mod_full_name %{vagrant_plugin_name}-%{version}
Name:           %{vagrant_plugin_name}
Version:        1.3.7
Release:        bp156.2.48
Summary:        SSHFS synced folder implementation for Vagrant
License:        GPL-2.0-only
URL:            https://github.com/dustymabe/%{name}
Source0:        %{URL}/releases/download/v%{version}/%{mod_full_name}.tar.gz
Source1:        %{URL}/releases/download/v%{version}/%{mod_full_name}.tar.gz.asc
# Dusty Mabe's key
Source2:        https://keybase.io/dustymabe/pgp_keys.asc#/%{name}.keyring
# custom script to automate the test suite run
Source3:        testsuite.sh
# FIX-OPENSUSE use the Tumbleweed.$(uname -m) vagrant box instead of fedora/*-cloud-base
Patch0:         0001-Use-opensuse-Tumbleweed.-uname-m-box-instead-of-Fedo.patch
BuildRequires:  %{ruby}
BuildRequires:  ruby-macros >= 5
BuildRequires:  vagrant >= 1.9.1
Requires:       sshfs
Requires:       vagrant >= 1.9.1
# for /usr/bin/fusermount
Requires:       fuse

%description
This Vagrant plugin adds synced folder support for mounting folders from the
Vagrant host into the Vagrant guest via SSHFS. In the default mode it does this
by executing the SSHFS client software within the guest, which creates an SSH
connection from the Vagrant guest back to the Vagrant host.

%package        -n %{name}-doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description    -n %{name}-doc
This package contains the documentation for the SSHFS provider to Vagrant.

%package        -n %{name}-testsuite
Summary:        Testsuite for %{name}
Group:          Development/Languages/Ruby
Requires:       vagrant-libvirt
Requires:       vagrant-sshfs = %{version}-%{release}

%description    -n %{name}-testsuite
This package contains the testsuite for the SSHFS provider for Vagrant. You most
likely do not want to install this package, unless you want to test
vagrant-sshfs.

%prep
%autosetup -c -p1

# since we don't have the full git repo we can't use `git ls-files`
sed -i 's/git ls-files -z/find . -type f -print0/' %{vagrant_plugin_name}.gemspec

# remove dependencies on windows libraries (needed for windows, not linux)
sed -i '/win32-process/d' %{vagrant_plugin_name}.gemspec
chmod +x test/misc/dotests.sh

mv %{vagrant_plugin_name}.gemspec %{mod_full_name}.gemspec

%build
%{gem_build}

%install
%vagrant_plugin_install -n %{mod_full_name}.gem
install -p -m 0755 %{SOURCE3} %{buildroot}/%{vagrant_plugin_instdir}/test/misc/

%files
%{vagrant_plugin_instdir}
%{vagrant_plugin_cache}
%{vagrant_plugin_spec}

%license LICENSE
%doc README.adoc

# files for development, we don't want these
%exclude %{vagrant_plugin_instdir}/.gitignore
%exclude %{vagrant_plugin_instdir}/Gemfile
%exclude %{vagrant_plugin_instdir}/Rakefile
%exclude %{vagrant_plugin_instdir}/RELEASE.txt
%exclude %{vagrant_plugin_instdir}/test

%exclude %{vagrant_plugin_instdir}/LICENSE
%exclude %{vagrant_plugin_instdir}/README.adoc

%files -n %{name}-doc
%license LICENSE
%doc %{vagrant_plugin_docdir}

%files -n %{name}-testsuite
%license LICENSE
%{vagrant_plugin_instdir}/test

%changelog
* Fri Jul  1 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Fix testsuite.sh: Follow changes of version 1.3.7, use
  reverse_mount with uid/gid (boo#1200894).
* Tue Jun 21 2022 Dan Čermák <dcermak@suse.com>
- New upstream release 1.3.7
  Dusty Mabe <dusty@dustymabe.com> (12):
    00f5737 guest: Enterprise Linux 9 has landed
    e90bbdb guest: add Alma Linux support
    e76db4d guest: handle Alma/Rocky until fixes land upstream
    b77809e add support for owner, group, and mount_options
    b37e1e5 tests: switch config.ssh.insert_key to boolean in Vagrantfile
    dba8c30 Update to Fedora 36 for build container and test VM
    cc887ad guest: upload fuse module loading for FreeBSD
    08c1c83 sshfs_reverse_mount: fixup botched copy/paste
    bf72f0f sshfs_reverse_mount: create guest directory if not exists
    51be8cb sshfs_reverse_mount: use ruby Etc lib for owner/group
    3f13f07 Gemfile: bump to latest versions of vagrant and vagrant-libvirt
    f60ff0e version: bump to 1.3.7
  Even Onsager <even.onsager@gmail.com> (3):
    ecb8c03 Add guest capabilities file for Rocky (based on CentOS)
    95e8ffc Add Rocky guest_capability to plugin.rb
    ade5564 Remove superfluous case/when (only rocky_8 exists)
* Mon Jun 13 2022 Dan Čermák <dcermak@suse.com>
- Add missing requires /usr/bin/fusermount
* Tue Feb  1 2022 Dan Čermák <dcermak@suse.com>
- Switch to default ruby for Tumbleweed
* Wed Nov  3 2021 Dan Čermák <dcermak@suse.com>
- Fix ruby macro usage
* Fri Oct  8 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- testsuite.sh: avoid reuse of existing directory or symlink from other users
  to prevent potential security issues (bsc#1182861)
* Thu Aug  5 2021 Dan Čermák <dcermak@suse.com>
- Build using ruby 3.0 on Tumbleweed
* Wed May  5 2021 Dan Čermák <dcermak@suse.com>
  New upstream release 1.3.6
  Thanks to the following contributors for patches during this release:
  Dominique Leuenberger <dimstar@opensuse.org> (1):
    cc2757e synced_folder: Add directory for SUSE/openSUSE to find sftp-server
  Dusty Mabe <dusty@dustymabe.com> (5):
    b5652a5 guest: centos: use lowercase for powertools repo
    c50fb6e More places where we can not pass file descriptors.
    4bef1db tests: update to use Fedora 34 vagrant box
    dd02818 Gemfile: bump to latest versions of vagrant and vagrant-libvirt
    0f5c864 version: bump to 1.3.6
  Ian2020 <Ian2020@users.noreply.github.com> (1):
    2615783 Fix #120: do not pass our file descriptors to spawned children
  Dropped patches:
- vagrant-sshfs-libexecdir.patch
  Rebased patches:
- 0001-Use-opensuse-Tumbleweed.-uname-m-box-instead-of-Fedo.patch
* Tue Sep  8 2020 Dan Čermák <dcermak@suse.com>
- Switch back to the default Ruby for Tumbleweed
* Thu Sep  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add vagrant-sshfs-libexecdir.patch: Use /usr/libexec/ssh to find
  sftp-server (boo#1176002).
* Mon Jun 29 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 1.3.5
  Dropped patches:
  * 0001-Use-var-run-run-symlink-for-tests.patch (merged upstream)
  * 0002-Use-opensuse-Tumbleweed.-uname-m-box-instead-of-Fedo.patch (rebased)
  Added patches:
  * 0001-Use-opensuse-Tumbleweed.-uname-m-box-instead-of-Fedo.patch
  Changelog for 1.3.5:
  Adam Butler <Adam.J.Butler@gmail.com> (1):
    eb6446f Add CentOS guest support for compatibility with Vagrant v2.2.8+
  Dan Čermák <dcermak@suse.com> (1):
    99a62bb Use /var/run/ -> /run symlink for tests
  Dusty Mabe <dusty@dustymabe.com> (7):
    3bc01b5 guest: centos: add a few comments into sshfs_client.rb
    1a0f440 guest: centos: rename module with capital OS
    f4408e3 guest: redhat: reset back to pre-EL8 modifications
    04235d9 guest: redhat: add best-effort support for RHEL8
    b1d92d9 Update vagrant in Gemfile to 2.2.9
    596360a tests: update to use Fedora 32 vagrant box
    fa27379 version: bump to 1.3.5
* Tue May 12 2020 Dan Čermák <dcermak@suse.com>
- Switch to Ruby 2.6 for Tumbleweed
* Wed Apr  1 2020 Dan Čermák <dcermak@suse.com>
- Fix test suite failures (boo#1168371)
  The testsuite was implicitly assuming that /sbin/ is a symlink to /usr/sbin
  (which is the case on Fedora, but not on opensuse). By switching to the
  /var/run -> /run symlink, we fix this issue.
  Also, the sed call in the spec file to change the Fedora box to
  opensuse/Tumbleweed.$(uname -m) got removed and instead was moved into the
  packaged Vagrantfile.
  Added patches:
  * 0001-Use-var-run-run-symlink-for-tests.patch
  * 0002-Use-opensuse-Tumbleweed.-uname-m-box-instead-of-Fedo.patch
* Tue Mar 31 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix vagrant-ssh-testsuite for aarch64 by using
  opensuse/Tumbleweed.$(uname -m) instead of fedora box which is
  for x86_64 only
* Mon Mar 16 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 1.3.4
  * guest: redhat: use yum to install epel-release
  * guest: redhat: pull fuse-sshfs from PowerTools repo on el8
  * guest: redhat: handle missing el8 version detection in vagrant
  * Update vagrant in Gemfile
  * RELEASE: update some release instructions
  * version: bump to 1.3.4
* Wed Jan 29 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 1.3.3
  v1.3.3:
  * RELEASE.txt: Updates to release process
  * synced_folder: gentoo: Update path to look for sftp-server
  * version: bump to 1.3.3
  v1.3.2:
  * remove tests - add build script
  * Fix some errors when building
  * Updates to build/release instructions
  * Update vagrant and vagrant-libvirt in Gemfile
  * Remove the build Vagrantfile
  * Run the build.sh script inside a buildah unshare session
  * guest: make alpine fuse module loading match what we do for freebsd
  * tests: update Vagrantfile to be Fedora 31
  * version: bump to 1.3.2
  * guest: Add alpine support
  * Add note for windows users to use cygwin shell.
- Drop patches:
  * 0001-Bump-testing-Vagrant-box-version.patch
  * 0001-remove-win32-dep.patch
- Add gpg source verification
- Drop not required dependencies on the rubygems mime-types, builder and ffi
* Thu Nov  7 2019 Dan Čermák <dcermak@suse.com>
- Add missing sshfs dependency
* Wed Oct  9 2019 Dan Čermák <dcermak@suse.com>
- Fix vagrant box name in testsuite.sh
* Fri Sep 27 2019 Dan Čermák <dcermak@suse.com>
- Fix in testsuite.sh:
  Ignore the return value of vagrant destroy -f in the cleanup function, so that
  all cleanup tasks run even if vagrant destroy fails
* Tue Sep 17 2019 Dan Čermák <dcermak@suse.com>
- Add working testsuite subpackage
* Thu Mar 14 2019 Dan Čermák <dcermak@suse.com>
- Initial package version
